
package org.ocap.hardware.device;

import org.dvb.media.VideoFormatControl;
import org.havi.ui.HScreenConfigTemplate;
import org.havi.ui.HVideoConfigTemplate;
import org.havi.ui.HVideoConfiguration;


/**
 * An interface that defines the constants that can be used for
 * specifying zoom mode preferences in an HVideoConfigTemplate.
 * 
 * @see VideoFormatControl
 * @see HVideoConfigTemplate
 */
public interface VideoZoomPreference 
{
   /**
    * A value for use in the preference field of the 
    * {@link HVideoConfigTemplate#setPreference(int, Object, int) setPreference},
    * {@link HVideoConfigTemplate#getPreferenceObject getPreferenceObject}
    * and
    * {@link HVideoConfigTemplate#getPreferencePriority getPreferencePriority}
    * methods in the {@link HVideoConfigTemplate} that indicates that
    * the <code>HVideoConfiguration</code> implies a specific decoder format conversion as
    * specified in an <code>Integer</code> object.
    * Valid preference objects for this preference are instances of <code>Integer</code> 
    * to be interpreted as a decoder format conversion constant for the profile
    * (e.g., one of the VideoFormatControl {@link VideoFormatControl DFC_* constants}).
    * <p>
    * The <code>ZOOM_MODE</code> preference SHALL be applied to convert input video
    * with one aspect ratio when presented on a full-screen <code>HVideoDevice</code>
    * with another display aspect ratio when not overridden by an application-directed
    * setting.  
    * That is, the <code>ZOOM_MODE</code> preference setting for the HVideoDevice is 
    * applied by default for newly created JMF Players or when 
    * {@link VideoFormatControl#DFC_PLATFORM} is the current decoder format conversion 
    * setting for a JMF <code>Player</code>.
    * <p>
    * Instances of {@link HVideoConfigTemplate} generated by the
    * platform and returned to applications (e.g., from 
    * {@link HVideoConfiguration#getConfigTemplate()} SHALL
    * have this preference set to a valid platform-supported DFC constant (as an
    * instance of <code>Integer</code>) with 
    * {@link HScreenConfigTemplate#REQUIRED REQUIRED} priority.  
	*/
	public static final int ZOOM_MODE = 0x2001;

}
